@@ -26,20 +26,21 @@ def activate_venv(path):
 
     # set current directory
     os.chdir(path)
-    os.system("python -m venv venv")
     print("🔨 setting up your virutal environment")
+    os.system("python -m venv venv")
 
     env_activate_script = ""
     if OS == "Windows":
         env_activate_script = "Scripts"
 
     activate_file = os.path.join(path, "env", env_activate_script, "activate")
-    os.system(f"{activate_file} && pip install -r requirements.txt")
     print("✏️ downloading packages")
+    os.system(f"{activate_file} && pip install -r requirements.txt")
 
 
 @app.command("")
 def main(template_name):
+    print("🔨 setting up your project")
     template_path = get_template_path(template_name)
     path = cookiecutter(template_path)
     activate_venv(path)
@@ -47,5 +48,5 @@ def main(template_name):
     folder_name = pathlib.PurePath(path)
     if OS == "Windows":
         activate_file = os.path.join(path, "env", "Scripts", "activate")
-        print(f"cd {folder_name} && {activate_file}")
+        print(f"cd {folder_name.name} && {activate_file}")
 
